@@ -57,7 +57,7 @@ int main(int argc, char * argv[])
             cmd = "/bin/sh";
 	    fprintf(stderr, "\nUsage: %s [-a arg0] cmd [args...]\n\n", argv[0]);
 	    fprintf(stderr, "Use the 'root' command to spawn a shell.");
-	    fprintf(stderr, "\nIf you messed up sudoers and really need rootsh to spawn a root shell, run rootsh /bin/sh. \nBut *always* use the 'root' command instead where possible.\n\n");
+	    fprintf(stderr, "\nIf you messed up sudoers, for example, and really need rootsh to spawn a root shell, run rootsh /bin/sh. \nBut *always* use the 'root' command instead where possible.\n\n");
 	    return 1;
 
         strcpy(sh, "-sh"); argv[0] = sh; argv[1] = NULL; args = argv;
@@ -78,7 +78,7 @@ int main(int argc, char * const argv[])
     extern char ** environ;
     argv[0][0] = '-'; argv[0][1] = 's'; argv[0][2] = 'h'; argv[0][3] = 0;
     fprintf(stderr, "Use the 'root' command to spawn a shell.");
-    fprintf(stderr, "\nIf you messed up sudoers and really need rootsh to spawn a root shell, run rootsh /bin/sh. \nBut *always* use the 'root' command instead where possible.\n\n");
+    fprintf(stderr, "\nIf you messed up sudoers, for example, and really need rootsh to spawn a root shell, run rootsh /bin/sh. \nBut *always* use the 'root' command instead where possible.\n\n");
     return 1;
     return execve("/bin/sh", argv, environ);
 }
